package com.jenkins.demo.service;

import com.jenkins.demo.model.User;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.atomic.AtomicLong;

/**
 * User Service Implementation
 * 提供用户管理的业务逻辑
 */
@Service
public class UserService {
    
    private final Map<Long, User> users = new ConcurrentHashMap<>();
    private final AtomicLong idGenerator = new AtomicLong(1);
    
    public UserService() {
        // 初始化一些测试数据
        initializeTestData();
    }
    
    /**
     * 获取所有用户
     */
    public List<User> getAllUsers() {
        return new ArrayList<>(users.values());
    }
    
    /**
     * 根据ID获取用户
     */
    public Optional<User> getUserById(Long id) {
        return Optional.ofNullable(users.get(id));
    }
    
    /**
     * 根据用户名查找用户
     */
    public Optional<User> getUserByUsername(String username) {
        return users.values().stream()
                .filter(user -> user.getUsername().equals(username))
                .findFirst();
    }
    
    /**
     * 创建新用户
     */
    public User createUser(User user) {
        if (getUserByUsername(user.getUsername()).isPresent()) {
            throw new IllegalArgumentException("用户名已存在: " + user.getUsername());
        }
        
        Long id = idGenerator.getAndIncrement();
        user.setId(id);
        user.setStatus("ACTIVE");
        users.put(id, user);
        return user;
    }
    
    /**
     * 更新用户信息
     */
    public Optional<User> updateUser(Long id, User userUpdates) {
        User existingUser = users.get(id);
        if (existingUser == null) {
            return Optional.empty();
        }
        
        // 检查用户名是否被其他用户使用
        if (!existingUser.getUsername().equals(userUpdates.getUsername())) {
            Optional<User> userWithSameUsername = getUserByUsername(userUpdates.getUsername());
            if (userWithSameUsername.isPresent() && !userWithSameUsername.get().getId().equals(id)) {
                throw new IllegalArgumentException("用户名已存在: " + userUpdates.getUsername());
            }
        }
        
        existingUser.setUsername(userUpdates.getUsername());
        existingUser.setEmail(userUpdates.getEmail());
        existingUser.setName(userUpdates.getName());
        
        return Optional.of(existingUser);
    }
    
    /**
     * 删除用户
     */
    public boolean deleteUser(Long id) {
        return users.remove(id) != null;
    }
    
    /**
     * 获取用户总数
     */
    public long getUserCount() {
        return users.size();
    }
    
    /**
     * 激活用户
     */
    public boolean activateUser(Long id) {
        User user = users.get(id);
        if (user != null) {
            user.setStatus("ACTIVE");
            return true;
        }
        return false;
    }
    
    /**
     * 停用用户
     */
    public boolean deactivateUser(Long id) {
        User user = users.get(id);
        if (user != null) {
            user.setStatus("INACTIVE");
            return true;
        }
        return false;
    }
    
    /**
     * 初始化测试数据
     */
    private void initializeTestData() {
        createUser(new User(null, "admin", "admin@jenkins-demo.com", "系统管理员", null));
        createUser(new User(null, "user1", "user1@jenkins-demo.com", "张三", null));
        createUser(new User(null, "user2", "user2@jenkins-demo.com", "李四", null));
    }
}
